from mower.utils.scene import Scene
from mower.utils.solver import BaseSolver


class Score(BaseSolver):
    solver_name = "曲谱"

    timeline = {
        "主题曲": [],
        "方舟": [],
        "那被祝福的": [],
        "山雪与银铁": [],
        "七丘的新芽": [],
        "霓虹之下": [],
        "岁岁今朝": [],
        "摘取未来之人": [],
        "自海渊的一瞥": [],
        "高塔迷影": [],
        "薪火重燃": [],
        "夏日律动": ["OF"],
        "泰拉奇谈": [],
    }

    def run(self, target: str):
        dash = target.rfind("-")
        self.prefix = target[0:dash]
        self.suffix = target[dash + 1 :]
        return super().run()

    @property
    def group(self) -> str | None:
        for group_name, prefix_list in self.timeline.items():
            if self.prefix in prefix_list:
                return group_name

    def find_group(self) -> str | None:
        for key in self.timeline.keys():
            if self.find(f"navigation/score/small/{key}"):
                return key

    def transition(self):
        if (scene := self.scene()) == Scene.TERMINAL_SCORE:
            if self.find("navigation/score/circle"):
                if self.find(f"navigation/score/large/{self.group}"):
                    if pos := self.find("navigation/score/timeline/OF"):
                        self.ctap(pos, 5)
                        return
                    # TODO: OF以外的关卡
                    self.swipe_ext([(300, 580), (1600, 580)], [500], 800)
                    return
                self.ctap("navigation/score/circle", 5)
                return
            if pos := self.find(f"navigation/score/large/{self.group}"):
                self.ctap(pos, 5)
                return
            if pos := self.find(f"navigation/score/small/{self.group}"):
                self.ctap(pos, 5)
                return
            groups = list(self.timeline.keys())
            index = groups.index(self.group)
            group = self.find_group()
            if groups.index(group) < index:
                self.swipe_ext([(180, 750), (180, 300)], [300], 500)
                return
            self.swipe_ext([(180, 300), (180, 750)], [300], 500)
        elif scene == Scene.TERMINAL_PREVIOUS:
            self.ctap((1700, 924), 5)
        elif scene == Scene.OPERATOR_CHOOSE_LEVEL:
            return True
        else:
            self.scene_graph_step(Scene.TERMINAL_SCORE)
