from datetime import datetime
from typing import List, Optional

from pydantic import BaseModel


class GachaPoolClient(BaseModel):
    gachaPoolId: str  # 卡池ID
    gachaIndex: int  # 卡池索引
    openTime: int  # 开始时间戳
    endTime: int  # 结束时间戳
    gachaPoolName: str  # 卡池名称
    gachaPoolSummary: str  # 卡池概述
    gachaPoolDetail: Optional[str] = None  # 卡池详细信息
    guarantee5Avail: int  # 保证5星次数
    guarantee5Count: int  # 保证5星次数计数
    LMTGSID: Optional[str] = None  # 可选字段
    CDPrimColor: Optional[str] = None  # 可选字段
    CDSecColor: Optional[str] = None  # 可选字段
    freeBackColor: Optional[str] = None  # 可选字段
    gachaRuleType: str  # 卡池规则类型
    dynMeta: Optional[dict] = None  # 动态元数据
    linkageRuleId: Optional[str] = None  # 可选字段
    linkageParam: Optional[dict] = None  # 可选字段
    limitParam: Optional[dict] = None  # 可选字段

    def get_start_time(self) -> datetime:
        """返回卡池开始时间"""
        return datetime.fromtimestamp(self.openTime)

    def get_end_time(self) -> datetime:
        """返回卡池结束时间"""
        return datetime.fromtimestamp(self.endTime)

    def is_active(self, current_timestamp: int) -> bool:
        """判断卡池是否正在进行"""
        return self.openTime <= current_timestamp < self.endTime


class limitTenGacha(BaseModel):
    itemId: str
    endTime: int


class linkageTenGacha(BaseModel):
    itemId: str
    endTime: int


class normalGacha(BaseModel):
    itemId: str
    endTime: int


class GachaData(BaseModel):
    gachaPoolClient: List[GachaPoolClient]
    limitTenGachaItem: List[limitTenGacha]
    linkageTenGachaItem: List[linkageTenGacha]
    normalGachaItem: List[normalGacha]
    recruitDetail: str

    def 读取卡池(self):
        """读取当前开放的卡池,暂无输出"""
        卡池类型映射 = {
            "SINGLE": "单人池",
            "LIMITED": "限定池",
            "NORM": "普通池",
            "CLASSIC": "中坚池",
            "CLASSIC_ATTAIN": "跨年中坚池",
            "LINKAGE": "联动池",
            "ATTAIN": "跨年池",
            "FESCLASSIC": "中坚甄选",
        }
        当前时间戳 = datetime.now().timestamp()
        for 项 in self.gachaPoolClient:
            卡池名称 = 项.gachaPoolName
            开始时间戳 = 项.openTime
            结束时间戳 = 项.endTime
            卡池类型代码 = 项.gachaPoolId
            卡池出人 = 项.dynMeta

            if 当前时间戳 < 结束时间戳:
                卡池类型 = 卡池类型映射.get(卡池类型代码.split("_")[0], 卡池类型代码)
                if 卡池类型代码.split("_")[1] == "ATTAIN":
                    卡池类型 = "跨年中坚池"
                if 卡池名称 == "适合多种场合的强力干员":
                    卡池名称 = 卡池类型
                开始时间 = datetime.fromtimestamp(开始时间戳)
                结束时间 = datetime.fromtimestamp(结束时间戳 + 1)
                print("卡池名称:", 卡池名称)
                print("卡池类型:", 卡池类型)
                if 卡池类型 == "中坚池":
                    print(
                        卡池出人["main6RarityCharId"],
                        卡池出人["sub6RarityCharId"],
                        卡池出人["rare5CharList"],
                    )
                if 当前时间戳 > 开始时间戳:
                    print("正在进行")
                    print("卡池结束时间:", 结束时间)
                else:
                    print("卡池开始时间:", 开始时间)
                    print("卡池结束时间:", 结束时间)
                print(卡池类型代码)
                print()

        return None
