from typing import Dict, List, Optional

from pydantic import BaseModel, field_validator


# 定义 stageDropList 类
class StageDropList(BaseModel):
    stageId: Optional[str]  # 可选的字段
    occPer: Optional[str]  # 可选的字段


class VoucherRelate(BaseModel):
    voucherId: str
    voucherItemType: str


class buildingProduct(BaseModel):
    roomType: str
    formulaId: str


# 定义 Item 类
class Item(BaseModel):
    itemId: Optional[str]
    name: Optional[str]
    description: Optional[str]

    iconId: Optional[str]
    overrideBkg: Optional[str]
    stackIconId: Optional[str]
    sortId: int
    usage: Optional[str]
    obtainApproach: Optional[str]
    hideInItemGet: Optional[bool] = False
    classifyType: Optional[str]
    itemType: Optional[str]
    stageDropList: Optional[List[StageDropList]] = []
    buildingProductList: Optional[List[buildingProduct]] = []
    voucherRelateList: Optional[List[VoucherRelate]] = []
    rarity: Optional[str]

    @field_validator("rarity", mode="before")
    @classmethod
    def convert_rarity_format(cls, value):
        """自动转换 rarity 字段格式"""
        if value is None:
            return None

        # 情况1：输入是整数（如 4）
        if isinstance(value, int):
            return str(value)

        # 情况2：输入是字符串（如 "TIER_4"）
        if isinstance(value, str):
            # 提取最后一个字符（兼容 "4" 或 "TIER_4" 格式）
            return value[-1]

        # 其他类型抛出错误
        raise ValueError(f"无效的 rarity 类型: {type(value)}")


# 定义 Items 类
class Items(BaseModel):
    items: Dict[str, Item]
